##### R functions to provide evaluations of prior, likelihood and posterior for the
##### linear model, plus sampling from the prior

# theta is vector of parameters; obsdata is 2 column dataframe with names [x,y].
# The priors are hard-wired into the functions

# return c(log10(prior), log10(likelihood)) (each generally unnormalized) of the linear model
logpost.linearmodel <- function(theta, obsdata, ind=NULL) {
  logprior <- logprior.linearmodel(theta)
  if(is.finite(logprior)) { # only evaluate model if parameters are sensible
    return( c(logprior, loglike.linearmodel(theta, obsdata, ind)) ) 
  } else {
    return( c(-Inf, -Inf) )
  }
}

# return log10(likelihood) for parameters theta for rows ind in obsdata
# (do all if ind not specified)
# dnorm(..., log=TRUE) returns log base e, so multiply by 1/ln(10) = 0.4342945
# to get log base 10
loglike.linearmodel <- function(theta, obsdata, ind=NULL) {
  if(is.null(ind)) ind <- 1:nrow(obsdata)
  # convert alpha to b_1 and log10(ysig) to ysig
  theta[2] <- tan(theta[2])
  theta[3] <- 10^theta[3]
  modPred <- drop( theta[1:2] %*% t(cbind(1,obsdata[ind,]$x)) )
  # Dimensions in mixed vector matrix multiplication: [Ndat] = [P] %*% [P x Ndat] 
  logLike <- (1/log(10))*sum( dnorm(modPred - obsdata[ind,]$y, mean=0,
                                    sd=theta[3], log=TRUE) ) # scalar
  return(logLike)
}

# return log10(unnormalized prior)
logprior.linearmodel <- function(theta) {
  b0Prior      <- dnorm(theta[1], mean=0, sd=2)
  alphaPrior   <- 1
  logysigPrior <- 1 
  logPrior <- sum( log10(b0Prior), log10(alphaPrior), log10(logysigPrior) ) # scalar
  return(logPrior)
}
